import { API as API$1 } from '../../../scw/api.js';
import { unmarshalServiceInfo } from '../../../scw/custom-marshalling.js';
import { enrichForPagination } from '../../../scw/fetch/resource-paginator.js';
import { validatePathParam, urlParams } from '../../../helpers/marshalling.js';
import { marshalCreateJobDefinitionRequest, unmarshalJobDefinition, unmarshalListJobDefinitionsResponse, marshalUpdateJobDefinitionRequest, unmarshalJobRun, unmarshalListJobRunsResponse } from './marshalling.gen.js';

// This file was automatically generated. DO NOT EDIT.
// If you have any remark or suggestion do not hesitate to open an issue.
const jsonContentHeaders = {
  'Content-Type': 'application/json; charset=utf-8'
};

/** Serverless Jobs API. */
class API extends API$1 {
  /** Lists the available regions of the API. */
  static LOCALITIES = ['fr-par', 'nl-ams', 'pl-waw'];
  getServiceInfo = (() => {
    var _this = this;
    return function (request) {
      if (request === void 0) {
        request = {};
      }
      return _this.client.fetch({
        method: 'GET',
        path: `/serverless-jobs/v1alpha1/regions/${validatePathParam('region', request.region ?? _this.client.settings.defaultRegion)}`
      }, unmarshalServiceInfo);
    };
  })();
  createJobDefinition = request => this.client.fetch({
    body: JSON.stringify(marshalCreateJobDefinitionRequest(request, this.client.settings)),
    headers: jsonContentHeaders,
    method: 'POST',
    path: `/serverless-jobs/v1alpha1/regions/${validatePathParam('region', request.region ?? this.client.settings.defaultRegion)}/job-definitions`
  }, unmarshalJobDefinition);
  getJobDefinition = request => this.client.fetch({
    method: 'GET',
    path: `/serverless-jobs/v1alpha1/regions/${validatePathParam('region', request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam('jobDefinitionId', request.jobDefinitionId)}`
  }, unmarshalJobDefinition);
  pageOfListJobDefinitions = (() => {
    var _this2 = this;
    return function (request) {
      if (request === void 0) {
        request = {};
      }
      return _this2.client.fetch({
        method: 'GET',
        path: `/serverless-jobs/v1alpha1/regions/${validatePathParam('region', request.region ?? _this2.client.settings.defaultRegion)}/job-definitions`,
        urlParams: urlParams(['order_by', request.orderBy], ['page', request.page], ['page_size', request.pageSize ?? _this2.client.settings.defaultPageSize], ['project_id', request.projectId])
      }, unmarshalListJobDefinitionsResponse);
    };
  })();
  listJobDefinitions = (() => {
    var _this3 = this;
    return function (request) {
      if (request === void 0) {
        request = {};
      }
      return enrichForPagination('jobDefinitions', _this3.pageOfListJobDefinitions, request);
    };
  })();
  updateJobDefinition = request => this.client.fetch({
    body: JSON.stringify(marshalUpdateJobDefinitionRequest(request, this.client.settings)),
    headers: jsonContentHeaders,
    method: 'PATCH',
    path: `/serverless-jobs/v1alpha1/regions/${validatePathParam('region', request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam('jobDefinitionId', request.jobDefinitionId)}`
  }, unmarshalJobDefinition);
  deleteJobDefinition = request => this.client.fetch({
    method: 'DELETE',
    path: `/serverless-jobs/v1alpha1/regions/${validatePathParam('region', request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam('jobDefinitionId', request.jobDefinitionId)}`
  });
  startJobDefinition = request => this.client.fetch({
    body: '{}',
    headers: jsonContentHeaders,
    method: 'POST',
    path: `/serverless-jobs/v1alpha1/regions/${validatePathParam('region', request.region ?? this.client.settings.defaultRegion)}/job-definitions/${validatePathParam('jobDefinitionId', request.jobDefinitionId)}/start`
  }, unmarshalJobRun);
  getJobRun = request => this.client.fetch({
    method: 'GET',
    path: `/serverless-jobs/v1alpha1/regions/${validatePathParam('region', request.region ?? this.client.settings.defaultRegion)}/job-runs/${validatePathParam('jobRunId', request.jobRunId)}`
  }, unmarshalJobRun);
  stopJobRun = request => this.client.fetch({
    body: '{}',
    headers: jsonContentHeaders,
    method: 'POST',
    path: `/serverless-jobs/v1alpha1/regions/${validatePathParam('region', request.region ?? this.client.settings.defaultRegion)}/job-runs/${validatePathParam('jobRunId', request.jobRunId)}/stop`
  }, unmarshalJobRun);
  pageOfListJobRuns = (() => {
    var _this4 = this;
    return function (request) {
      if (request === void 0) {
        request = {};
      }
      return _this4.client.fetch({
        method: 'GET',
        path: `/serverless-jobs/v1alpha1/regions/${validatePathParam('region', request.region ?? _this4.client.settings.defaultRegion)}/job-runs`,
        urlParams: urlParams(['job_definition_id', request.jobDefinitionId], ['order_by', request.orderBy], ['page', request.page], ['page_size', request.pageSize ?? _this4.client.settings.defaultPageSize], ['project_id', request.projectId])
      }, unmarshalListJobRunsResponse);
    };
  })();
  listJobRuns = (() => {
    var _this5 = this;
    return function (request) {
      if (request === void 0) {
        request = {};
      }
      return enrichForPagination('jobRuns', _this5.pageOfListJobRuns, request);
    };
  })();
}

export { API };
